//
// C++ Interface: CLampEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CLAMPEDITDLG_H
#define CLAMPEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_lampdlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CLampEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CLampEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CLampEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
    virtual void slotEditColorAmb();
    virtual void slotEditColorSpe();
    virtual void slotEditColorDif();

    
private slots:
 
protected:
    Ui::LampEditDlg ui;    
    FolderListItem *point;
    QColor mycolor_dif;
    QColor mycolor_spe;
    QColor mycolor_amb;
    
private:
    QWidget *myParent;
};
#endif
